@@ -228,7 +228,7 @@ def land(base: str = option_base, bypass_accepted_check: bool = False):
     commits = list(repo.iter_commits(f"{base}..HEAD"))
     if not phab_utils.are_commits_all_accepted(*commits) and not bypass_accepted_check:
         display_utils.print_error("All the diffs must be accepted before you can land.")
-        exit(0)
+        sys.exit(0)
     print("Before landing, this script needs to pull and rebase.")
     print("Right now, Stackler only supports landing onto the git upstream, "
           + "so the rebase command about to run is `git pull --rebase`. "
